@@ -6,4 +6,5 @@ cd ../barbell2/createh5
 python createh5.py \
     /Volumes/USB_SECURE1/data/radiomics/projects/deepseg/data/mega/final \
     ${HOME}/Desktop/h5 \
-    --training="HEERLEN, NEWEPOC, OVPRIMDEB" --validation="OVT1" --test="PANCREAS"
+    --split="HEERLEN, NEWEPOC" \
+    --split_percentage=0.8
